package com.ruoyi.project.business.mapper;

import java.util.List;
import com.ruoyi.project.business.domain.TcProjectHistory;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2024-07-22
 */
public interface TcProjectHistoryMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param projectId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TcProjectHistory selectTcProjectHistoryByProjectId(Long projectId, Long version);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tcProjectHistory 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TcProjectHistory> selectTcProjectHistoryList(TcProjectHistory tcProjectHistory);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tcProjectHistory 【请填写功能名称】
     * @return 结果
     */
    public int insertTcProjectHistory(TcProjectHistory tcProjectHistory);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tcProjectHistory 【请填写功能名称】
     * @return 结果
     */
    public int updateTcProjectHistory(TcProjectHistory tcProjectHistory);

    /**
     * 删除【请填写功能名称】
     * 
     * @param projectId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTcProjectHistoryByProjectId(Long projectId);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param projectIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcProjectHistoryByProjectIds(Long[] projectIds);
}
