package com.ruoyi.project.business.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.business.domain.TcProjectHistory;
import com.ruoyi.project.business.service.ITcProjectHistoryService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2024-07-22
 */
@RestController
@RequestMapping("/business/project/history")
public class TcProjectHistoryController extends BaseController
{
    @Autowired
    private ITcProjectHistoryService tcProjectHistoryService;

    /**
     * 查询【请填写功能名称】列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TcProjectHistory tcProjectHistory)
    {
        startPage();
        List<TcProjectHistory> list = tcProjectHistoryService.selectTcProjectHistoryList(tcProjectHistory);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcProjectHistory tcProjectHistory)
    {
        List<TcProjectHistory> list = tcProjectHistoryService.selectTcProjectHistoryList(tcProjectHistory);
        ExcelUtil<TcProjectHistory> util = new ExcelUtil<TcProjectHistory>(TcProjectHistory.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @GetMapping(value = "/{projectId}/{version}")
    public AjaxResult getInfo(@PathVariable("projectId") Long projectId, @PathVariable("version") Long version)
    {
        return success(tcProjectHistoryService.selectTcProjectHistoryByProjectId(projectId, version));
    }

    /**
     * 新增【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TcProjectHistory tcProjectHistory)
    {
        return toAjax(tcProjectHistoryService.insertTcProjectHistory(tcProjectHistory));
    }

    /**
     * 修改【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TcProjectHistory tcProjectHistory)
    {
        return toAjax(tcProjectHistoryService.updateTcProjectHistory(tcProjectHistory));
    }

    /**
     * 删除【请填写功能名称】
     */
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{projectIds}")
    public AjaxResult remove(@PathVariable Long[] projectIds)
    {
        return toAjax(tcProjectHistoryService.deleteTcProjectHistoryByProjectIds(projectIds));
    }
}
